==> wetterdienst-0.99.0.tar.gz: wetterdienst-0.99.0/docs/data/provider/ea/hydrology/6_hours.md <==
# 6_hours

## metadata

| property      | value                                                                      |
|---------------|----------------------------------------------------------------------------|
| name          | 6_hours                                                                    |
| original name | 6_hours                                                                    |
| description   | no specific dataset is provided but parameters can be queried individually |
| url           | [here](https://environment.data.gov.uk/hydrology/doc/reference)            |

## datasets

### data

#### metadata

| property      | value                                                                            |
|---------------|----------------------------------------------------------------------------------|
| name          | data                                                                             |
| original name | data                                                                             |
| description   | Historical 6 hours station observations of flow and groundwater level for the UK |
| access        | [here](https://environment.data.gov.uk/hydrology/doc/reference)                  |

#### parameters

| name              | original name     | description                    | unit | original unit | constraints |
|-------------------|-------------------|--------------------------------|------|---------------|-------------|
| flow              | water flow        | 6 hours mean flow              | m³/s | m³/s          | >=0         |
| groundwater_level | groundwater level | 6 hours mean groundwater level | m    | m             | >=0         |

==> wetterdienst-0.103.0.tar.gz: wetterdienst-0.103.0/docs/data/provider/ea/hydrology/6_hours.md <==
# 6_hours

## metadata

| property      | value                                                                      |
|---------------|----------------------------------------------------------------------------|
| name          | 6_hours                                                                    |
| original name | 6_hours                                                                    |
| description   | no specific dataset is provided but parameters can be queried individually |
| url           | [here](https://environment.data.gov.uk/hydrology/doc/reference)            |

## datasets

### data

#### metadata

| property      | value                                                                            |
|---------------|----------------------------------------------------------------------------------|
| name          | data                                                                             |
| original name | data                                                                             |
| description   | Historical 6 hours station observations of flow and groundwater level for the UK |
| access        | [here](https://environment.data.gov.uk/hydrology/doc/reference)                  |

#### parameters

| name              | original name     | description                    | unit type       | unit          | constraints |
|-------------------|-------------------|--------------------------------|-----------------|---------------|-------------|
| flow              | water flow        | 6 hours mean flow              | volume_per_time | m³/s          | >=0         |
| groundwater_level | groundwater level | 6 hours mean groundwater level | length_medium   | m             | >=0         |
